# Karnak Data Platform Community Libraries

Karnak Data Platform is an opinionated framework for building big data and AI systems.

This package contains a collection of open sourced utility libraries that are part of the
Karnak Data Platform framework.

## Libraries included

- **karnak.util.argparse**: argparse validators.
- **karnak.util.athena**: helper library for querying AWS Athena with performance for
  small or large results.

- **karnak.util.log**: convenience logging functions.
- **karnak.util.path**: file system path helper functions.
- **karnak.util.profiling**: memory profiling and timing helper functions.